calcCvxHullFaces returns the parameters of the convex
hull of X: The indices of points in X that compose the faces of conv(X)
(one row per face) as well as the parameters of the hyperplanes that
describe these faces.
calcCvxHullFaces(X)Set of data points (one sample per row)
A list consisting of parameters describing the convex hull of X:
A matrix of indices where each row constitutes one face
A matrix where each row constitutes the normal vector of a face
A vector where each entry constitutes the offset of the hyperplane for a face